Canonicalizer

Struct Canonicalizer 

pub struct Canonicalizer<R, W> { /* private fields */ }
Canonicalizers take XML and return the canonicalised form of that XML.

Implementations

Source

impl<R, W> Canonicalizer<R, W>

pub fn read_from_reader(reader: R) -> Self

Initialize a new Canonicalizer that reads from the provided reader.

Source

impl<'a, W> Canonicalizer<&'a [u8], W>

pub fn read_from_str(str: &'a str) -> Self

Initialize a new Canonicalizer that reads from the provided str.

Source

impl<W> Canonicalizer<BufReader<File>, W>

pub fn read_from_file<P: AsRef<Path>>(path: P) -> Result<Self, Arc<Error>>

Initialize a new Canonicalizer that reads from the provided str.

Errors

Returns an I/O error if the file couldn’t be opened and/or read.

Source

impl<R, W: Write> Canonicalizer<R, W>

pub fn write_to_writer(self, writer: W) -> Self

Set the writer for this Canonicalizer to a writer.

Source

impl<R> Canonicalizer<R, BufWriter<File>>

pub fn write_to_file<P: AsRef<Path>>(self, path: P) -> Result<Self, Error>

Set the writer for this Canonicalizer to a file.

Errors

Returns an I/O error if the file couldn’t be opened and/or read.

Source

impl<R: BufRead, W: Write> Canonicalizer<R, W>

pub fn canonicalize(self, retain_comments: bool) -> Result<(), Error>

Start canonicalizing the document to the writer.

Errors

Returns an XML error if the XML parsed is invalid.

Panics

This will panic is a writer has not been initialised with write_to_string, write_to_file, or write_to_writer.