pub struct Canonicalizer<R, W> { /* private fields */ }Expand description
Canonicalizers take XML and return the canonicalised form of that XML.
Implementations
Sourceimpl<R, W> Canonicalizer<R, W>
impl<R, W> Canonicalizer<R, W>
Sourcepub fn read_from_reader(reader: R) -> Self
pub fn read_from_reader(reader: R) -> Self
Initialize a new Canonicalizer that reads from the provided
reader.
Sourceimpl<'a, W> Canonicalizer<&'a [u8], W>
impl<'a, W> Canonicalizer<&'a [u8], W>
Sourcepub fn read_from_str(str: &'a str) -> Self
pub fn read_from_str(str: &'a str) -> Self
Initialize a new Canonicalizer that reads from the provided
str.
Sourceimpl<W> Canonicalizer<BufReader<File>, W>
impl<W> Canonicalizer<BufReader<File>, W>
Sourcepub fn read_from_file<P: AsRef<Path>>(path: P) -> Result<Self, Arc<Error>>
pub fn read_from_file<P: AsRef<Path>>(path: P) -> Result<Self, Arc<Error>>
Initialize a new Canonicalizer that reads from the provided
str.
Errors
Returns an I/O error if the file couldn’t be opened and/or read.
Sourceimpl<R, W: Write> Canonicalizer<R, W>
impl<R, W: Write> Canonicalizer<R, W>
Sourcepub fn write_to_writer(self, writer: W) -> Self
pub fn write_to_writer(self, writer: W) -> Self
Set the writer for this Canonicalizer to a writer.
Sourceimpl<R> Canonicalizer<R, BufWriter<File>>
impl<R> Canonicalizer<R, BufWriter<File>>